@@ -34,7 +34,7 @@ __copyright__ = "This software is copyrighted to Galen Data and is only availabl
                 "License are non transferable unless agreed upon in the subscription contract. "
 __credits__ = ["Nathanael Goza", "Abbas Dhilawala"]
 __license__ = "Proprietary"
-__version__ = "1.0"
+__version__ = "1.0.1"
 __maintainer__ = "Nathanael Goza"
 __email__ = "support@galendata.com"
 __status__ = "Development"
@@ -44,7 +44,7 @@ __status__ = "Development"
 def date_time_data_formater(date_time: datetime):
     """
     Helper function to format datetime into data that can be used to save_data
-    :param date_time: datetime date to turn into
+    :param date_time: the datetime date to format
     :return: a string version of the datetime that will be accepted by the save(s)_data functions
     """
     return date_time_formater(date_time)
@@ -53,7 +53,7 @@ def date_time_data_formater(date_time: datetime):
 def date_data_formater(date: datetime):
     """
     Helper function to format dates into data that can be used to save_data
-    :param date: datetime date to turn into
+    :param date: the date date to format
     :return: a string version of the date that will be accepted by the save(s)_data functions
     """
     return date_formater(date)
@@ -985,6 +985,24 @@ class SDK:
         :param deviceDataModelId: deviceDataModelId. Required.       [Device Data > manage Data > in URL]
         :param devicePropertySetId: devicePropertySetId. Required.   [Devices List > Edit > Data model edit > in URL]
         :param data: data in dictionary form. Property code as key and the value as the value. Required.
+            example_data = {
+               "propertyCode": desired_data
+            }
+            Depending on the data type there are different ways to input the desired_data:
+                Date Time                   Date_time_formater(datetime_value)
+                Json                        json.dumps(Dict)
+                Height                      Number
+                Blood Pressure              String with "systolic-pressure-value/diastolic-pressure-value"
+                Dropdown List               String with the Dropdown Option as its innards ie) "Dropdown Value 3"
+                Geographical Cooridnates    String that represents the coordinates
+                Number                      Number
+                Number Array                Number Array
+                Temperature                 Number
+                Text                        String
+                Weight                      Number
+                Xml                         String that represents the Xml
+                Yes No                      Use True or False       (kinda acts like text but true/false works best)
+                Date                        Date_formater(date_value)
         :param deviceDataId: ID of the deviceData. If not supplied, ID is auto generated. Optional.
         :param ownerId: ownerId. Optional.
         :return: Returns the Id of the created data
